@@ -1,5 +1,5 @@
 # Load.pm -- Schedule load management
-# $Id: Load.pm,v 1.36 2000/01/21 14:26:04 wsnyder Exp $
+# $Id: Load.pm,v 1.38 2000/11/03 20:53:26 wsnyder Exp $
 ######################################################################
 #
 # This program is Copyright 2000 by Wilson Snyder.
@@ -44,12 +44,13 @@ use Carp;
 ######################################################################
 #### Configuration Section
 
-$VERSION = '1.2';
+$VERSION = '1.3';
 $Debug = 0;
 
 %_Default_Params = (
 		    min_pctcpu=>3,
-		    port=>1752,
+		    port=>(getservbyname ('slchoosed',"")
+			   ? 'slchoosed' : 1752),
 		    dhost=> [(defined $ENV{SLCHOOSED_HOST})
 			     ? split ':', $ENV{SLCHOOSED_HOST}
 			     : qw(localhost)],
