@@ -1,5 +1,5 @@
 # Schedule::Load::Chooser.pm -- distributed lock handler
-# $Id: Chooser.pm,v 1.13 2000/01/21 14:31:09 wsnyder Exp $
+# $Id: Chooser.pm,v 1.15 2000/11/03 20:53:31 wsnyder Exp $
 ######################################################################
 #
 # This program is Copyright 2000 by Wilson Snyder.
@@ -47,7 +47,7 @@ use Carp;
 # Other configurable settings.
 $Debug = $Schedule::Load::Debug;
 
-$VERSION = '1.2';
+$VERSION = '1.3';
 
 ######################################################################
 #### Globals
@@ -589,7 +589,8 @@ Starts the chooser daemon.  Does not return.
 
 =item port
 
-The port number of slchoosed.  Defaults to 1752.
+The port number of slchoosed.  Defaults to 'slchoosed' looked up via
+/etc/services, else 1752.
 
 =item dead_time
 
